@@ -28,14 +28,34 @@ print(dim(pl))
 pl <- pl_select_standard(pl, clean_names = TRUE)
 print(pl)
 
-## ----message=F, warning=F-----------------------------------------------------
+## ----message=F, warning=F, eval = FALSE---------------------------------------
+#  library(tinytiger)
+#  library(sf)
+#  library(dplyr)
+#  library(ggplot2)
+#  
+#  ri_tracts = tt_tracts("RI", county="Providence", year=2020)
+
+## ---- echo = FALSE------------------------------------------------------------
 library(tinytiger)
 library(sf)
 library(dplyr)
 library(ggplot2)
+with_retry <- function(fn, ..., max_iter = 5) {
+    out <- NULL
+    i <- 1
+    try({out <- fn(...)}, silent = TRUE)
+    while (i <= max_iter && is.null(out)) {
+        Sys.sleep(0.5)
+        try({out <- fn(...)}, silent = TRUE)
+        i <- i + 1
+    } 
+    out
+}
 
-ri_tracts = tt_tracts("RI", county="Providence", year=2020)
+ri_tracts = with_retry(fn = tt_tracts, state = "RI", county = "Providence", year = 2020)
 
+## ---- eval = !is.null(ri_tracts)----------------------------------------------
 full_join(pl, ri_tracts, by="GEOID") %>%
 ggplot(aes(fill=pop, geometry=geometry)) +
     geom_sf(size=0) +
